@@ -1,6 +1,7 @@
 import collections.abc
 import math
 import torch
+import torchvision
 import warnings
 from itertools import repeat
 from torch import nn as nn
@@ -226,8 +227,12 @@ class DCNv2Pack(ModulatedDeformConvPack):
             logger = get_root_logger()
             logger.warning(f'Offset abs mean is {offset_absmean}, larger than 50.')
 
-        return modulated_deform_conv(x, offset, mask, self.weight, self.bias, self.stride, self.padding, self.dilation,
-                                     self.groups, self.deformable_groups)
+        if torchvision.__version__ >= '0.9.0':
+            return torchvision.ops.deform_conv2d(x, offset, self.weight, self.bias, self.stride, self.padding,
+                                                 self.dilation, mask)
+        else:
+            return modulated_deform_conv(x, offset, mask, self.weight, self.bias, self.stride, self.padding,
+                                         self.dilation, self.groups, self.deformable_groups)
 
 
 def _no_grad_trunc_normal_(tensor, mean, std, a, b):
